/**
 * @description 创建子页面功能。
 * @param {String} url 要创建子页面的地址;
 * @param {String} top 距顶部的高度;
 * @param {String} bottom 距底部的高度;
 * @example 
 * createsubpage("index.html","45px","0")
 */
function createsubpage(url, top, bottom) {
	//启用双击监听
	mui.init({
		swipeBack: false,
		gestureConfig: {
			doubletap: true
		},
		subpages: [{
			url: url,
			id: url,
			styles: {
				top: top,
				bottom: bottom
			}
		}]
	});
}

/**
 * @description 双击回到头部。
 * @param {String} pullrefresh 选择器,子页面容器名称;
 * @example 
 * doubletapheader("#pullrefresh")
 */
function doubletapheader(pullrefresh) {
	//双击回到头部
	var contentWebview = null;
	document.querySelector('header').addEventListener('doubletap', function() {
		if (contentWebview == null) {
			contentWebview = plus.webview.currentWebview().children()[0];
		}
		contentWebview.evalJS("mui('" + pullrefresh + "').pullRefresh().scrollTo(0,0,100)");
	});
}


/**
 * @description 打开新页面
 * @param {String} url 设置新页面地址;
 * @param {String} id  设置新页面id;
 * @param {String} data 需要传递的参数;
 * @param {String} width 设置新页面的宽;
 * @param {String} height 设置新页面的高;
 * @example 
 * openwindow("index.html","index",{type:"1",name:"2"},'100%','100%');
 */
function openwindow(url, id, data, width, height) {
	mui.openWindow({
		url: url,
		id: id,
		styles: {
			width: width,
			height: height
		}, //窗口参数
		show: {
			autoShow: true,
			aniShow: 'pop-in'
		},
		waiting: {
			autoShow: true,
			title: "正在加载..."
		},
		extras: data
	})
}

/**
 * @description 预加载页面，一次仅能预加载一个页面，若需要加载多个，则需要多次调用
 * @param {String} url 设置新页面地址;
 * @param {String} id  设置新页面id;
 * @param {String} data 需要传递的参数;
 * @param {String} width 设置新页面的宽;
 * @param {String} height 设置新页面的高;
 * @example 
 * openpreloadpage("index.html","index",{type:"1",name:"2"},'100%','100%');
 */
function openpreloadpage(url, id, data, width, height) {
	mui.preload({
		url: url,
		id: id,
		styles: {
			width: width,
			height: height
		}, //窗口参数
		show: {
			autoShow: false,
			aniShow: 'pop-in'
		},
		createNew: true,
		waiting: {
			autoShow: true,
			title: "正在加载..."
		},
		extras: data
	});

}

			/**
 * @description  批量元素的事件绑定
 * @param {String} 外容器类名  
 * @param {String} 元素类型
 * @example 
 * openhref(".class1","a");
 */
function openhref(class1,a){
	mui(class1).on('tap','a',function(){
  //获取id
  var id = this.getAttribute("id");
  var href=this.getAttribute("href");
  //打开新闻详情
	mui.openWindow({
		url: href,
		id: id,
		styles: {
			width: '100%',
			height: '100%'
		}, //窗口参数
		show: {
			autoShow: true,
			aniShow: 'pop-in'
		},
		waiting: {
			autoShow: true,
			title: "正在加载..."
		}
	})
  }) 
}
